<a href="https://explosion.ai"><img src="https://explosion.ai/assets/img/logo.svg" width="125" height="125" align="right" /></a>

# thinc-apple-ops

Make [thinc](https://thinc.ai) faster on MacOS by calling into Apple's native libraries.
